@@ -1,4 +1,3 @@
-from django.conf import settings
 from django.utils.translation import ugettext_lazy as _
 from debug_logging.utils import get_revision
 from debug_toolbar.panels import DebugPanel
@@ -14,16 +13,16 @@ class RevisionLoggingPanel(DebugPanel):
 
     def nav_title(self):
         return _('Revision')
-    
+
     def nav_subtitle(self):
         return self.get_revision() or 'Revision unavailable'
-    
+
     def process_response(self, request, response):
-        if getattr(settings, 'DEBUG_LOGGING_CONFIG', {}).get('ENABLED', False):
+        if getattr(request, 'debug_logging', {}).get('ENABLED', False):
             # Logging is enabled, so log the revision
             request.debug_logging_stats.update({
                 'revision': self.get_revision()
             })
-    
+
     def get_revision(self):
         return get_revision()
