@@ -4,7 +4,7 @@ from debug_toolbar.panels.timer import TimerDebugPanel
 
 class TimerLoggingPanel(TimerDebugPanel):
     """Extends the Timer debug panel to enable logging."""
-    
+
     def get_stats(self):
         """
         Taken from the beginning of TimerDebugPanel's 'content' method.
@@ -15,14 +15,14 @@ class TimerLoggingPanel(TimerDebugPanel):
         ivcsw = self._elapsed_ru('ru_nivcsw')
         minflt = self._elapsed_ru('ru_minflt')
         majflt = self._elapsed_ru('ru_majflt')
-        
+
         return utime, stime, vcsw, ivcsw, minflt, majflt
-    
+
     def process_response(self, request, response):
         response = super(TimerLoggingPanel, self).process_response(
             request, response)
-        
-        if getattr(settings, 'DEBUG_LOGGING_CONFIG', {}).get('ENABLED', False):
+
+        if getattr(request, 'debug_logging', {}).get('ENABLED', False):
             utime, stime, vcsw, ivcsw, minflt, majflt = self.get_stats()
             stats = {
                 'timer_utime': utime,
@@ -33,5 +33,5 @@ class TimerLoggingPanel(TimerDebugPanel):
                 'timer_ivcsw': ivcsw,
             }
             request.debug_logging_stats.update(stats)
-        
+
         return response
